mailr13208 - in /branches/gui_testing/gui/analyses: auto_model_free.py auto_noe.py auto_rx_base.py


Others Months | Index by Date | Thread Index
>>   [Date Prev] [Date Next] [Thread Prev] [Thread Next]

Header


Content

Posted by edward on June 23, 2011 - 21:33:
Author: bugman
Date: Thu Jun 23 21:33:41 2011
New Revision: 13208

URL: http://svn.gna.org/viewcvs/relax?rev=13208&view=rev
Log:
The data pipe name is now passed in the auto-analysis tabs and stored in the 
relax data store.


Modified:
    branches/gui_testing/gui/analyses/auto_model_free.py
    branches/gui_testing/gui/analyses/auto_noe.py
    branches/gui_testing/gui/analyses/auto_rx_base.py

Modified: branches/gui_testing/gui/analyses/auto_model_free.py
URL: 
http://svn.gna.org/viewcvs/relax/branches/gui_testing/gui/analyses/auto_model_free.py?rev=13208&r1=13207&r2=13208&view=diff
==============================================================================
--- branches/gui_testing/gui/analyses/auto_model_free.py (original)
+++ branches/gui_testing/gui/analyses/auto_model_free.py Thu Jun 23 21:33:41 
2011
@@ -154,15 +154,17 @@
 
 
 class Auto_model_free(Base_frame):
-    def __init__(self, gui, analysis_name, notebook, data_index=None):
+    def __init__(self, gui=None, notebook=None, analysis_name=None, 
pipe_name=None, data_index=None):
         """Build the automatic model-free protocol GUI element.
 
-        @param gui:             The main GUI class.
+        @keyword gui:           The main GUI class.
         @type gui:              gui.relax_gui.Main instance
-        @param analysis_name:   The name of the analysis (the name in the 
tab part of the notebook).
+        @keyword notebook:      The notebook to pack this frame into.
+        @type notebook:         wx.Notebook instance
+        @keyword analysis_name: The name of the analysis (the name in the 
tab part of the notebook).
         @type analysis_name:    str
-        @param notebook:        The notebook to pack this frame into.
-        @type notebook:         wx.Notebook instance
+        @keyword pipe_name:     The name of the data pipe associated with 
this analysis.
+        @type pipe_name:        str
         @keyword data_index:    The index of the analysis in the relax data 
store (set to None if no data currently exists).
         @type data_index:       None or int
         """
@@ -175,8 +177,9 @@
             # Generate a storage container in the relax data store, and 
alias it for easy access.
             data_index = ds.relax_gui.analyses.add('model-free')
 
             # Store the analysis name.
             ds.relax_gui.analyses[data_index].analysis_name = analysis_name
+            ds.relax_gui.analyses[data_index].pipe_name = pipe_name
 
             # Model-free variables.
             ds.relax_gui.analyses[data_index].model_source = getcwd()
@@ -175,8 +177,9 @@
             data_index = ds.relax_gui.analyses.add('model-free')
 
-            # Store the analysis name.
+            # Store the analysis and pipe names.
             ds.relax_gui.analyses[data_index].analysis_name = analysis_name

Modified: branches/gui_testing/gui/analyses/auto_noe.py
URL: 
http://svn.gna.org/viewcvs/relax/branches/gui_testing/gui/analyses/auto_noe.py?rev=13208&r1=13207&r2=13208&view=diff
==============================================================================
--- branches/gui_testing/gui/analyses/auto_noe.py (original)
+++ branches/gui_testing/gui/analyses/auto_noe.py Thu Jun 23 21:33:41 2011
@@ -60,15 +60,17 @@
     bitmap = None
     label = None
 
-    def __init__(self, gui, analysis_name, notebook, data_index=None):
+    def __init__(self, gui=None, notebook=None, analysis_name=None, 
pipe_name=None, data_index=None):
         """Build the automatic NOE analysis GUI frame elements.
 
-        @param gui:             The main GUI class.
+        @keyword gui:           The main GUI class.
         @type gui:              gui.relax_gui.Main instance
-        @param analysis_name:   The name of the analysis (the name in the 
tab part of the notebook).
+        @keyword notebook:      The notebook to pack this frame into.
+        @type notebook:         wx.Notebook instance
+        @keyword analysis_name: The name of the analysis (the name in the 
tab part of the notebook).
         @type analysis_name:    str
-        @param notebook:        The notebook to pack this frame into.
-        @type notebook:         wx.Notebook instance
+        @keyword pipe_name:     The name of the data pipe associated with 
this analysis.
+        @type pipe_name:        str
         @keyword data_index:    The index of the analysis in the relax data 
store (set to None if no data currently exists).
         @type data_index:       None or int
         """
@@ -81,8 +83,9 @@
             # Generate a storage container in the relax data store, and 
alias it for easy access.
             data_index = ds.relax_gui.analyses.add('NOE')
 
             # Store the analysis name.
             ds.relax_gui.analyses[data_index].analysis_name = analysis_name
+            ds.relax_gui.analyses[data_index].pipe_name = pipe_name
 
             # Initialise the variables.
             ds.relax_gui.analyses[data_index].frq = ''
@@ -81,8 +83,9 @@
             data_index = ds.relax_gui.analyses.add('NOE')
 
-            # Store the analysis name.
+            # Store the analysis and pipe names.
             ds.relax_gui.analyses[data_index].analysis_name = analysis_name

Modified: branches/gui_testing/gui/analyses/auto_rx_base.py
URL: 
http://svn.gna.org/viewcvs/relax/branches/gui_testing/gui/analyses/auto_rx_base.py?rev=13208&r1=13207&r2=13208&view=diff
==============================================================================
--- branches/gui_testing/gui/analyses/auto_rx_base.py (original)
+++ branches/gui_testing/gui/analyses/auto_rx_base.py Thu Jun 23 21:33:41 2011
@@ -60,15 +60,17 @@
     bitmap = None
     label = None
 
-    def __init__(self, gui, analysis_name, notebook, data_index=None):
+    def __init__(self, gui=None, notebook=None, analysis_name=None, 
pipe_name=None, data_index=None):
         """Build the automatic R1 and R2 analysis GUI frame elements.
 
-        @param gui:             The main GUI class.
+        @keyword gui:           The main GUI class.
         @type gui:              gui.relax_gui.Main instance
-        @param analysis_name:   The name of the analysis (the name in the 
tab part of the notebook).
+        @keyword notebook:      The notebook to pack this frame into.
+        @type notebook:         wx.Notebook instance
+        @keyword analysis_name: The name of the analysis (the name in the 
tab part of the notebook).
         @type analysis_name:    str
-        @param notebook:        The notebook to pack this frame into.
-        @type notebook:         wx.Notebook instance
+        @keyword pipe_name:     The name of the data pipe associated with 
this analysis.
+        @type pipe_name:        str
         @keyword data_index:    The index of the analysis in the relax data 
store (set to None if no data currently exists).
         @type data_index:       None or int
         """
@@ -81,8 +83,9 @@
             # Generate a storage container in the relax data store, and 
alias it for easy access.
             data_index = ds.relax_gui.analyses.add(self.label)
 
             # Store the analysis name.
             ds.relax_gui.analyses[data_index].analysis_name = analysis_name
+            ds.relax_gui.analyses[data_index].pipe_name = pipe_name
 
             # Initialise the variables.
             ds.relax_gui.analyses[data_index].frq = ''
@@ -81,8 +83,9 @@
             data_index = ds.relax_gui.analyses.add(self.label)
 
-            # Store the analysis name.
+            # Store the analysis and pipe names.
             ds.relax_gui.analyses[data_index].analysis_name = analysis_name




Related Messages


Powered by MHonArc, Updated Thu Jun 23 22:00:01 2011